@@ -18,28 +18,6 @@ def banner():
         "\n                                    Created by [bold]Gaurav Raj[/bold]\n                                      [[bold green]TheHackersBrain[/bold green]]\n")
 
 
-def menu():
-    print("[bold yellow][00] Basic Recon (Site Title, IP Address, CMS, Cloudflare Detection, Robots.txt Scanner)[/bold yellow]")
-    print("[bold yellow][01] Whois Lookup[/bold yellow]")
-    print("[bold yellow][02] Geo-IP Lookup[/bold yellow]")
-    print("[bold yellow][03] Grab Banners[/bold yellow]")
-    print("[bold yellow][04] DNS Lookup[/bold yellow]")
-    print("[bold yellow][05] Subnet Calculator[/bold yellow]")
-    print("[bold yellow][06] NMAP Port Scan[/bold yellow]")
-    print("[bold yellow][07] Subdomain Scanner[/bold yellow]")
-    print("[bold yellow][08] Reverse IP Lookup & CMS Detection[/bold yellow]")
-    print("[bold yellow][09] SQLi Scanner[/bold yellow]")
-    print("[bold yellow][10] Bloggers View[/bold yellow]")
-    print("[bold yellow][11] Wordpress Scanner[/bold yellow]")
-    print("[bold yellow][12] Crawler[/bold yellow]")
-    print("[bold yellow][13] MX Lookup[/bold yellow]")
-    print("[bold magenta][A] Scan for Everything[/bold magenta]")
-    print("[bold blue][F] Fix Modules[/bold blue]")
-    print("[bold green][U] Check for Updates[/bold green]")
-    print("[bold][B] Scan Another Website[/bold]")
-    print("[bold red][Q] QUIT !!![/bold red]")
-
-
 def scan_type(stype):
     print(" [[bold green]S[/bold green]] Scan Type: [[bold green]{}[/bold green]]\n".format(stype))
 
